==> impresscms-1.0.2.tbz: www/impresscms/htdocs/language/english/comment.php <==
<?php
// $Id: comment.php 506 2006-05-26 23:10:37Z skalpa $
define('_CM_TITLE','Title');
define('_CM_MESSAGE','Message');
define('_CM_DOSMILEY','Enable Smiley Icons');
define('_CM_DOHTML','Enable HTML Tags');
define('_CM_DOAUTOWRAP','Auto wrap lines');
define('_CM_DOXCODE','Enable iCMS Codes');
define('_CM_REFRESH','Refresh');
define('_CM_PENDING','Pending');
define('_CM_HIDDEN','Hidden');
define('_CM_ACTIVE','Active');
define('_CM_STATUS','Status');
define('_CM_POSTCOMMENT','Post Comment');
define('_CM_REPLIES','Replies');
define('_CM_PARENT','Parent');
define('_CM_TOP','Top');
define('_CM_BOTTOM','Bottom');
define('_CM_ONLINE','Online!');
define('_CM_POSTED','Posted'); // Posted date
define('_CM_UPDATED', 'Updated');
define('_CM_THREAD','Thread');
define('_CM_POSTER','Poster');
define('_CM_JOINED','Joined');
define('_CM_POSTS','Posts');
define('_CM_FROM','From');
define('_CM_COMDELETED', 'Comment(s) deleted.');
define('_CM_COMDELETENG', 'Could not delete comment.');
define('_CM_DELETESELECT' , 'Delete all its child comments?');
define('_CM_DELETEONE' , 'No, delete only this comment');
define('_CM_DELETEALL', 'Yes, delete all');
define('_CM_THANKSPOST', 'Thanks for posting!');
define('_CM_NOTICE', "The comments are owned by the poster. We aren't responsible for their content.");
define('_CM_COMRULES','Comment Rules');
define('_CM_COMAPPROVEALL','Comments are always approved');
define('_CM_COMAPPROVEUSER','Comments by registered users are always approved');
define('_CM_COMAPPROVEADMIN','All comments need to be approved by administrator');
define('_CM_COMANONPOST','Allow anonymous post in comments?');
define('_CM_COMNOCOM','Disable comments');
define('_CM_RE','Re');
?>

==> impresscms-1.2.3.tbz: www/impresscms/htdocs/language/english/comment.php <==
<?php
// $Id: comment.php 9536 2009-11-13 18:59:32Z pesianstranger $
define('_CM_TITLE','Title');
define('_CM_MESSAGE','Message');
define('_CM_DOSMILEY','Enable Smiley Icons');
define('_CM_DOHTML','Enable HTML Tags');
define('_CM_DOAUTOWRAP','Enable Linebreaks');
define('_CM_DOXCODE','Enable iCMS Codes');
define('_CM_REFRESH','Refresh');
define('_CM_PENDING','Pending');
define('_CM_HIDDEN','Hidden');
define('_CM_ACTIVE','Active');
define('_CM_STATUS','Status');
define('_CM_POSTCOMMENT','Post Comment');
define('_CM_REPLIES','Replies');
define('_CM_PARENT','Parent');
define('_CM_TOP','Top');
define('_CM_ONLINE','Online!');
define('_CM_POSTED','Posted'); // Posted date
define('_CM_UPDATED', 'Updated');
define('_CM_THREAD','Thread');
define('_CM_POSTER','Poster');
define('_CM_JOINED','Joined');
define('_CM_POSTS','Posts');
define('_CM_FROM','From');
define('_CM_COMDELETED', 'Comment(s) deleted.');
define('_CM_COMDELETENG', 'Could not delete comment.');
define('_CM_DELETESELECT' , 'Delete all its child comments?');
define('_CM_DELETEONE' , 'No, delete only this comment');
define('_CM_DELETEALL', 'Yes, delete all');
define('_CM_THANKSPOST', 'Thanks for posting!');
define('_CM_NOTICE', "The comments are owned by the poster. We aren't responsible for their content.");
define('_CM_COMRULES','Comment Rules');
define('_CM_COMAPPROVEALL','Comments are always approved');
define('_CM_COMAPPROVEUSER','Comments by registered users are always approved');
define('_CM_COMAPPROVEADMIN','All comments need to be approved by administrator');
define('_CM_COMANONPOST','Allow anonymous post in comments?');
define('_CM_COMNOCOM','Disable comments');
define('_CM_RE','Re');
############# added since 1.2 #############
define('_CM_COULDNOTCHANGEPIDTOID', 'Could not change comment parent ID from <b>%s</b> to <b>%s</b>. (ID: %s)');
define('_CM_COULDNOTCHANGEROOTID', 'Could not change comment root ID from <b>%s</b> to <b>%s</b>.');
define('_CM_COULDNOTCHANGEPAID', 'Could not change comment parent ID from <b>%s</b> to <b>%s</b>.');
define('_CM_COULDNOTUPDATEPOSTS', 'Could not update user posts.');
?>
